Module stomp_parser::server [−][src]
Implements the model for the frames that a STOMP server can send, as specified in the STOMP Protocol Spezification,Version 1.2.
Structs
This frame has required headers version and optional headers heartbeat,session,server.
This frame has required headers .
This frame has required headers message_id,destination,subscription and optional headers content_type,content_length.
This frame has required headers receipt_id.
Enums
The ServerFrame enum contains a variant for each frame that the server can send.